pub trait ProtocolManager { // Required method fn stop(&mut self); }
Protocol manager used to stop the protocol
Stop the protocol Note that we do not take self by value to consume it because it is not allowed to move out of Box This will improve if the unsized_fn_params feature stabilizes enough to be safely usable.
unsized_fn_params